@@ -6,7 +6,12 @@ use strict;
 use warnings;
 use Perl::Tidy qw();
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
+
+# Regex to match balanced parans. Reproduced from Regexp::Common to avoid
+# adding a non-core dependency.
+#   $RE{balanced}{-parens=>'()'};
+our $Clause = '(?^:((?:\((?:(?>[^\(\)]+)|(?-1))*\))))';
 
 sub perltidy {
     return Perl::Tidy::perltidy(
@@ -24,9 +29,9 @@ sub prefilter {
     # Convert func xxxx (signature) -> sub
     s{^\s*\K            # okay to have leading whitespace (preserve)
       func   \s+        # the "func" keyword
-      (\w+)  \s*        # the function name
-      (\([^)]*\))?      # optional parameter list (multi-line ok)
-      (.*?)             # anything else (ie, comments)
+      (\w+)  \s*        # the function name ($1)
+      (?:$Clause)?      # optional parameter list (multi-line ok) ($2 in Clause)
+      (.*?)             # anything else (ie, comments) ($3)
       $
      }{sub $1 $3 \#__FUNC @{[ escape_params( $2 ) ]}}gxm;
 
@@ -34,9 +39,9 @@ sub prefilter {
     # encode multi-line parameter lists into one with escaped "\n"
     s{^\s*\K            # ok to have leading whitespace (preserve)
       method \s+        # the "method" keyword
-      (\w+)  \s*        # the method name
-      (\([^)]*\))?      # optional parameter list (multi-line ok)
-      (.*?)             # anything else (ie, comments)
+      (\w+)  \s*        # the method name ($1)
+      (?:$Clause)?      # optional parameter list (multi-line ok) ($2 in Clause)
+      (.*?)             # anything else (ie, comments) ($3)
       $
     }{sub $1 $3 \#__METHOD @{[ escape_params( $2 ) ]}}xgm;
 
@@ -51,40 +56,40 @@ sub postfilter {
     # Convert back to func
     s{^\s*\K              # preserve leading whitespace
       sub \s+             # func was converted to sub
-      (\w+)\b             # the function name and a break
-      (.*?) [ ]*          # anything else originally following the declaration
+      (\w+)\b             # the function name and a break ($1)
+      (.*?) [ ]*          # anything originally following the declaration ($2)
       \#__FUNC            # our magic token
-      ( [ ] \([^)]*\) )?  # optional parameter list
+      (\s $Clause)?       # optional parameter list ($3 & $4 in Clause)
       [ ]*                # trailing spaces
     }{func $1@{[ unescape_params( $3 ) ]}$2}xgm;
 
     # Check to see if tidy turned it into "sub name\n{ #..."
     s{^\s*\K            # preserve leading whitespace
       sub \s+           # method was converted to sub
-      (\w+)\n           # the method name and a newline
-      \s* \{(.*?) [ ]*  # the opening brace on a newline followed orig comments
+      (\w+)\n           # the method name and a newline ($1)
+      \s* \{(.*?) [ ]*  # opening brace on a newline followed orig comments ($2)
       \#__FUNC          # our magic token
-      ([ ]\([^)]*\))?   # optional parameter list
+      (\s $Clause)?     # optional parameter list ($3 & $4 in Clause)
       [ ]*              # trailing spaces
     }{func $1@{[ unescape_params( $3 ) ]} \{$2}gmx;
 
     # Convert back to method
     s{^\s*\K            # preserve leading whitespace
       sub \s+           # method was convert to sub
-      (\w+)\b           # the method name and a word break
-      (.*?)[ ]*         # anything else originally following the declaration
+      (\w+)\b           # the method name and a word break ($1)
+      (.*?)[ ]*         # anything originally following the declaration ($2)
       \#__METHOD        # out magic token
-      ([ ]\([^)]*\))?   # option parameter list
+      (\s $Clause)?     # option parameter list ($3 & $4 in Clause)
       [ ]*              # trailing spaces
     }{method $1@{[ unescape_params( $3 ) ]}$2}gmx;
 
     # Check to see if tidy turned it into "sub name\n{ #..."
     s{^\s*\K            # preserve leading whitespace
       sub \s+           # method was converted to sub
-      (\w+)\n           # the method name and a newline
-      \s* \{(.*?) [ ]*  # the opening brace on a newline followed orig comments
+      (\w+)\n           # the method name and a newline ($1)
+      \s* \{(.*?) [ ]*  # opening brace on newline followed orig comments ($2)
       \#__METHOD        # our magic token
-      ([ ]\([^)]*\))?   # optional parameter list
+      (\s $Clause)?     # optional parameter list ($3 & $4 in Clause)
       [ ]*              # trailing spaces
     }{method $1@{[ unescape_params( $3 ) ]} \{$2}gmx;
 
@@ -119,7 +124,7 @@ Perl::Tidy::Sweetened - Tweaks to Perl::Tidy to support some syntactic sugar
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 DESCRIPTION
 
